# Roadmap

!!! NOTE
    The roadmap represents the general direction of the project, and is subject
    to change based on need and developer bandwidth.

## The road to stable

The primary focus of pre-release versions is completing the base functionality
and ensuring stability.

**Planned features**

* Database experiment backend
* Debug toolbar panel
* Django admin support
